# compas_tna

[![GitHub - License](https://img.shields.io/github/license/blockresearchgroup/compas_tna.svg)](https://github.com/blockresearchgroup/compas_tna)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/compas-tna.svg)](https://pypi.python.org/project/compas-tna)
[![PyPI - Latest Release](https://img.shields.io/pypi/v/compas-tna.svg)](https://pypi.python.org/project/compas-tna)
[![DOI](https://zenodo.org/badge/113331502.svg)](https://zenodo.org/badge/latestdoi/113331502)
[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/blockresearchgroup/compas_tna/main?urlpath/lab/tree/notebooks)

COMPAS package for Thrust Network Analaysis.

## Documentation

To get started with `compas_tna` have a look at [the documentation](https://github.com/blockresearchgroup/compas_tna).

## Questions and Feedback

For questions and feedback, have a look at the [COMPAS Forum](https://forum.compas-framework.org).

## Issues

If you run into problems, please file an issue on the [issue tracker](https://github.com/blockresearchgroup/compas_tna/issues). If we don't know it is broken, we can't fix it...

## Contributing

Guidelines for developers are under construction. However, we always accept contributions in the form of Pull Requests.

## License

`compas_tna` is licensed under the MIT License. See [LICENSE](https://github.com/blockresearchgroup/compas_tna/blob/main/LICENSE), for more information.
